@@ -1,10 +1,9 @@
 package MooX::Cmd::Tester;
-
+# ABSTRACT: MooX cli app commands tester
+our $VERSION = '1.000';
 use strict;
 use warnings;
 
-our $VERSION = "0.015";
-
 require Exporter;
 use Test::More import => ['!pass'];
 use Package::Stash;
@@ -22,22 +21,24 @@ BEGIN
 {
     *CORE::GLOBAL::exit = sub {
         return CORE::exit(@_) unless $TEST_IN_PROGRESS;
-        MooX::Cmd::Tester::Exited->throw( $_[0] );
+        MooX::Cmd::Tester::Exited->throw($_[0]);
     };
 }
 
+
 sub result_class { 'MooX::Cmd::Tester::Result' }
 
+
 sub test_cmd
 {
-    my ( $app, $argv ) = @_;
+    my ($app, $argv) = @_;
 
-    my $result = _run_with_capture( $app, $argv );
-    my $exit_code = defined $result->{error} ? ( ( 0 + $! ) || -1 ) : 0;
+    my $result    = _run_with_capture($app, $argv);
+    my $exit_code = defined $result->{error} ? ((0 + $!) || -1) : 0;
 
     $result->{error}
       and eval { $result->{error}->isa('MooX::Cmd::Tester::Exited') }
-      and $exit_code = ${ $result->{error} };
+      and $exit_code = ${$result->{error}};
 
     result_class->new(
         {
@@ -47,48 +48,50 @@ sub test_cmd
     );
 }
 
+
 sub test_cmd_ok
 {
     my $rv = test_cmd(@_);
 
-    my $test_ident = $rv->app . " => [ " . join( " ", @{ $_[1] } ) . " ]";
-    ok( !$rv->error, "Everythink ok running cmd $test_ident" ) or diag( $rv->error );
+    my $test_ident = $rv->app . " => [ " . join(" ", @{$_[1]}) . " ]";
+    ok(!$rv->error, "Everythink ok running cmd $test_ident") or diag($rv->error);
     # no error and cmd means, we're reasonable successful so far
     $rv
-      and !$rv->error
+      and not $rv->error
       and $rv->cmd
       and $rv->cmd->command_name
-      and ok( $rv->cmd->command_commands->{ $rv->cmd->command_name }, "found command at $test_ident" );
+      and ok($rv->cmd->command_commands->{$rv->cmd->command_name}, "found command at $test_ident");
 
     $rv;
 }
 
+## no critic qw(ProhibitSubroutinePrototypes)
 sub _capture_merged(&)
 {
     my $code = shift;
-    my ( $stdout, $stderr, $merged, $ok );
-    if ( $^O eq 'MSWin32' )
+    my ($stdout, $stderr, $merged, $ok);
+    if ($^O eq 'MSWin32')
     {
-        ( $stdout, $stderr, $ok ) = tee { $code->(); };
+        ($stdout, $stderr, $ok) = tee { $code->(); };
         $merged = $stdout . $stderr;
     }
     else
     {
         ($merged) = tee_merged
         {
-            ( $stdout, $stderr, $ok ) = tee { $code->() };
+            ($stdout, $stderr, $ok) = tee { $code->() };
         };
     }
-    ( $stdout, $stderr, $merged, $ok );
+    ($stdout, $stderr, $merged, $ok);
 }
 
 sub _run_with_capture
 {
-    my ( $app, $argv ) = @_;
+    my ($app, $argv) = @_;
 
-    my ( $execute_rv, $cmd, $cmd_name );
+    my ($execute_rv, $cmd, $cmd_name, $error);
 
-    my ( $stdout, $stderr, $merged, $ok ) = _capture_merged
+    my ($stdout, $stderr, $merged, $ok) = _capture_merged
     {
         eval {
             local $TEST_IN_PROGRESS = 1;
@@ -98,31 +101,30 @@ sub _run_with_capture
 
             $cmd = ref $app ? $app : $app->new_with_cmd;
             ref $app and $app = ref $app;
-            my $test_ident = "$app => [ " . join( " ", @$argv ) . " ]";
-            ok( $cmd->isa($app), "got a '$app' from new_with_cmd" );
+            my $test_ident = "$app => [ " . join(" ", @$argv) . " ]";
+            ok($cmd->isa($app), "got a '$app' from new_with_cmd");
             @$argv
-              and defined( $cmd_name = $cmd->command_name )
-              and ok( ( grep { $_ =~ m/$cmd_name/ } @$argv ), "proper cmd name from $test_ident" );
-            ok( scalar @{ $cmd->command_chain } <= 1 + scalar @$argv, "\$#argv vs. command chain length testing $test_ident" );
-            @$argv and ok( $cmd->command_chain_end == $cmd->command_chain->[-1], "command_chain_end ok" );
+              and defined($cmd_name = $cmd->command_name)
+              and ok((grep { index($cmd_name, $_) != -1 } @$argv), "proper cmd name from $test_ident");
+            ok(scalar @{$cmd->command_chain} <= 1 + scalar @$argv, "\$#argv vs. command chain length testing $test_ident");
+            @$argv and ok($cmd->command_chain_end == $cmd->command_chain->[-1], "command_chain_end ok");
 
-            unless ( $execute_rv = $cmd->execute_return )
+            unless ($execute_rv = $cmd->execute_return)
             {
-                my ( $command_execute_from_new, $command_execute_method_name );
+                my ($command_execute_from_new, $command_execute_method_name);
                 my $cce = $cmd->can("command_chain_end");
                 $cce                      and $cce                      = $cce->($cmd);
                 $cce                      and $command_execute_from_new = $cce->can("command_execute_from_new");
                 $command_execute_from_new and $command_execute_from_new = $command_execute_from_new->($cce);
                 $command_execute_from_new or $command_execute_method_name = $cce->can('command_execute_method_name');
                 $command_execute_method_name
-                  and $execute_rv = [ $cce->can( $command_execute_method_name->($cce) )->($cce) ];
+                  and $execute_rv = [$cce->can($command_execute_method_name->($cce))->($cce)];
             }
             1;
-        };
+        } or $error = 1;
+        $@ and $error = $@;
     };
 
-    my $error = $ok ? undef : $@;
-
     return {
         app        => $app,
         cmd        => $cmd,
@@ -135,12 +137,13 @@ sub _run_with_capture
 }
 
 {
+    ## no critic qw(ProhibitMultiplePackages)
     package    # no-index
       MooX::Cmd::Tester::Result;
 
     sub new
     {
-        my ( $class, $arg ) = @_;
+        my ($class, $arg) = @_;
         bless $arg => $class;
     }
 }
@@ -148,26 +151,41 @@ sub _run_with_capture
 my $res = Package::Stash->new("MooX::Cmd::Tester::Result");
 for my $attr (qw(app cmd stdout stderr output error execute_rv exit_code))
 {
-    $res->add_symbol( '&' . $attr, sub { $_[0]->{$attr} } );
+    $res->add_symbol('&' . $attr, sub { $_[0]->{$attr} });
 }
 
 {
+    ## no critic qw(ProhibitMultiplePackages)
     package    # no-index
       MooX::Cmd::Tester::Exited;
 
     sub throw
     {
-        my ( $class, $code ) = @_;
+        my ($class, $code) = @_;
         defined $code or $code = 0;
-        my $self = ( bless \$code => $class );
+        my $self = (bless \$code => $class);
+        ## no critic qw(RequireCarping)
         die $self;
     }
 }
 
+
+1;
+
+__END__
+
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
 MooX::Cmd::Tester - MooX cli app commands tester
 
+=head1 VERSION
+
+version 1.000
+
 =head1 SYNOPSIS
 
   use MooX::Cmd::Tester;
@@ -191,7 +209,10 @@ The test coverage of most CLI apps is somewhere between poor and wretched.
 With the same approach as L<App::Cmd::Tester> comes MooX::Cmd::Tester to
 ease writing tests for CLI apps.
 
-=head1 FUNCTIONS
+=head2 result_class
+
+Builder for result class to use. Returns C<MooX::Cmd::Tester::Result> by
+default.
 
 =head2 test_cmd
 
@@ -205,37 +226,25 @@ command_name and command_chain are not totally scrambled.
 
 It returns an object with following attributes/accessors:
 
-=head3 app
+=over
 
-Name of package of App
+=item app - Name of package of App
 
-=head3 cmd
+=item cmd - Name of executed (1st level) command
 
-Name of executed (1st level) command
+=item stdout - Content of stdout
 
-=head3 stdout
+=item stderr - Content of stderr
 
-Content of stdout
+=item output - Content of merged stdout and stderr
 
-=head3 stderr
+=item error - the exception thrown by running the application (if any)
 
-Content of stderr
+=item execute_rv - return values from execute
 
-=head3 output
+=item exit_code - 0 on success, $! when error occurred and $! available, -1 otherwise
 
-Content of merged stdout and stderr
-
-=head3 error
-
-the exception thrown by running the application (if any)
-
-=head3 execute_rv
-
-return values from execute
-
-=head3 exit_code
-
-0 on success, $! when error occurred and $! available, -1 otherwise
+=back
 
 =head2 test_cmd_ok
 
@@ -248,27 +257,36 @@ Returns the same object C<test_cmd> returns.
 
 If an error occurred, no additional test is done (behavior as C<test_cmd>).
 
-=head2 result_class
-
-Builder for result class to use. Returns C<MooX::Cmd::Tester::Result> by
-default.
-
 =head1 ACKNOWLEDGEMENTS
 
 MooX::Cmd::Tester is I<inspired> by L<App::Cmd::Tester> from Ricardo Signes.
 In fact, I reused the entire design and adopt it to the requirements of
 MooX::Cmd.
 
-=head1 LICENSE AND COPYRIGHT
+=head1 SUPPORT
 
-Copyright 2013-2015 Jens Rehsack.
+=head2 Issues
 
-This program is free software; you can redistribute it and/or modify it
-under the terms of either: the GNU General Public License as published
-by the Free Software Foundation; or the Artistic License.
+Please report bugs and feature requests on GitHub at
+L<https://github.com/Getty/p5-moox-cmd/issues>.
 
-See L<http://dev.perl.org/licenses/> for more information.
+=head2 IRC
+
+Join C<#web-simple> on C<irc.perl.org> or message Getty directly.
+
+=head1 CONTRIBUTING
+
+Contributions are welcome! Please fork the repository and submit a pull request.
+
+=head1 AUTHOR
+
+Torsten Raudssus <torsten@raudssus.de>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2026 by Torsten Raudssus.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
-
-1;
